@@ -43,30 +43,11 @@ class DDPSocket(WebSocketClient, EventEmitter):
         sys.stderr.write('{}\n'.format(msg))
 
     def once(self):
-        """ OVERRIDE FROM WebSocket
-        Performs the operation of reading from the underlying
-        connection in order to feed the stream of bytes.
-        We start with a small size of two bytes to be read
-        from the connection so that we can quickly parse an
-        incoming frame header. Then the stream indicates
-        whatever size must be read from the connection since
-        it knows the frame payload length.
-        It returns `False` if an error occurred at the
-        socket level or during the bytes processing. Otherwise,
-        it returns `True`."""
         # check for self.sock existence
         # https://github.com/hharnisc/python-meteor/issues/5
-        if self.terminated or not self.sock:
-            return False
-
-        try:
-            b = self.sock.recv(self.reading_buffer_size)
-        except socket.error:
-            return False
-        else:
-            if not self.process(b):
-                return False
-
+        if self.sock:
+            return super(DDPSocket, self).once()
+        return False
 
 
 class DDPClient(EventEmitter):
@@ -75,6 +56,7 @@ class DDPClient(EventEmitter):
         EventEmitter.__init__(self)
         self.ddpsocket = None
         self._is_closing = False
+        self._is_reconnecting = False
         self.url = url
         self.auto_reconnect = auto_reconnect
         self.auto_reconnect_timeout = auto_reconnect_timeout
@@ -111,8 +93,7 @@ class DDPClient(EventEmitter):
                 try:
                     self.connect()
                     connected = True
-                    self.ddpsocket._debug_log("* RECONNECTED")
-                    self.emit('reconnected')
+                    self._is_reconnecting = True
                 except (socket.error, WebSocketException):
                     pass
 
@@ -165,7 +146,13 @@ class DDPClient(EventEmitter):
 
         elif data['msg'] == 'connected':
             self._session = data.get('session')
-            self.emit('connected')
+            if self._is_reconnecting:
+                self.ddpsocket._debug_log("* RECONNECTED")
+                self.emit('reconnected')
+                self._is_reconnecting = False
+            else:
+                self.ddpsocket._debug_log("* CONNECTED")
+                self.emit('connected')
 
         # method result
         elif data['msg'] == 'result':
